package com.dgtly.notice.mapper;

import com.dgtly.notice.domain.NoticeSupply;
import java.util.List;

/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author dgtly
 * @date 2020-02-13
 */
public interface NoticeSupplyMapper 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    public NoticeSupply selectNoticeSupplyById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param noticeSupply 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<NoticeSupply> selectNoticeSupplyList(NoticeSupply noticeSupply);

    /**
     * 新增【请填写功能名称】
     * 
     * @param noticeSupply 【请填写功能名称】
     * @return 结果
     */
    public int insertNoticeSupply(NoticeSupply noticeSupply);

    /**
     * 修改【请填写功能名称】
     * 
     * @param noticeSupply 【请填写功能名称】
     * @return 结果
     */
    public int updateNoticeSupply(NoticeSupply noticeSupply);

    /**
     * 删除【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    public int deleteNoticeSupplyById(Long id);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteNoticeSupplyByIds(String[] ids);

    /**
     * @descption: 获取最新的供应信息前10条
     * @param:
     * @return:
     * @auther: LiuLingChao
     * @date: 2020-2-25 11:15
     */
    public List<NoticeSupply> getSupplyInfoTenList();

    /**
     * @descption: 网站获取供应信息列表
     * @param:
     * @return:
     * @auther: LiuLingChao
     * @date: 2020-3-3 9:15
     */

    public List<NoticeSupply> getSupplyInfoAllList(NoticeSupply noticeSupply);
}
